<?php

namespace App\Http\Middleware;

use App\Models\FileEvent;
use Closure;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;

class SetElfinderConfig
{
    public function handle($request, Closure $next)
    {
        $user = Auth::user();
        // $storage_path_url = 'shared/';
        // $storage_path_path = '/run/user/1001/gvfs/smb-share:server=192.168.6.230,share=development/1827/';

        $storage_path_url = 'storage/';
        $storage_path_path = 'storage/';

        if ($user) {
            $departmentPath = 'files/' . ($user->department->path ?? $user->file_no ?? "default");
        } else {
            $departmentPath = 'files/default';
        }
        if ($user->hasRole('team_member')) {
            $fullPath = $storage_path_path . $departmentPath . '/' . $user->name;
        } else {
            $fullPath = $storage_path_path;
        }

        $fullPath = $user->hasRole('auditor')
            ? $storage_path_path
            : ($user->hasRole('manager')
                ? $storage_path_path . $departmentPath
                : $storage_path_path . $departmentPath . '/' . $user->file_no);

        if (!File::exists($fullPath)) {
            File::makeDirectory($fullPath, 0775, true);
        }
        $URL = $user->hasRole('auditor')
            ? $storage_path_url
            : ($user->hasRole('manager')
                ? $storage_path_url . $departmentPath
                : $storage_path_url . $departmentPath . '/' . $user->file_no);
            config([
                'elfinder.roots' => [
                    [
                        'driver'        => 'LocalFileSystem',
                        'path'          => $fullPath,
                        'URL'           =>  $URL,
                        'accessControl' => function ($attr, $path, $data, $volume) use ($user) {
                            if ($user->hasRole('manager')) {
                                return null;
                            } elseif ($user->hasRole('team_member')) {
                                return ($attr === 'write' || $attr === 'read' || $attr === 'delete') ? null : false;
                            } elseif ($user->hasRole('auditor')) {
                                return ($attr === 'read') ? null : false;
                            }
                            return false; // Default to no access
                        },
                        'uploadAllow'   => ['all'],
                        'uploadDeny'    => ['all'],
                        'uploadOrder'   => ['deny', 'allow'],
                        'attributes'    => [
                            [
                                'pattern' => '/.*/',
                                'read'    => true,
                                'write'   => $user && ($user->hasRole('team_member') || $user->hasRole('manager')),
                                'locked'  => true,
                            ],
                        ],
                    ],
                ],

            ]);

        return $next($request);
    }
}
