<section>
    <header>
        <h2 class="text-lg font-medium text-gray-900 dark:text-gray-100">
            {{ __('Profile Information') }}
        </h2>

        <p class="mt-1 text-sm text-gray-600 dark:text-gray-400">
            {{ __("Update your account's profile information and email address.") }}
        </p>

    </header>
    <style>
        #is_manager:checked+.block {
            background-color: #4f46e5;
        }

        #is_manager:checked+.block .dot {
            transform: translateX(100%);
        }
    </style>
    <form id="send-verification" method="post" action="{{ route('verification.send') }}">
        @csrf
    </form>

    <form method="post" action="{{ route('profile.update', [ $user->id ]) }}" class="mt-6 space-y-6">
        @csrf
        @method('patch')

        <div>
            <x-input-label for="name" :value="__('Name')" />
            <x-text-input id="name" name="name" type="text" class="mt-1 block w-full" :value="old('name', $user->name)"
                required autofocus autocomplete="name" />
            <x-input-error class="mt-2" :messages="$errors->get('name')" />
        </div>

        <div>
            <x-input-label for="email" :value="__('Email')" />
            <x-text-input id="email" name="email" type="email" class="mt-1 block w-full" :value="old('email', $user->email)"
                required autocomplete="username" />
            <x-input-error class="mt-2" :messages="$errors->get('email')" />

            @if ($user instanceof \Illuminate\Contracts\Auth\MustVerifyEmail && !$user->hasVerifiedEmail())
                <div>
                    <p class="text-sm mt-2 text-gray-800 dark:text-gray-200">
                        {{ __('Your email address is unverified.') }}

                        <button form="send-verification"
                            class="underline text-sm text-gray-600 dark:text-gray-400 hover:text-gray-900 dark:hover:text-gray-100 rounded-md focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 dark:focus:ring-offset-gray-800">
                            {{ __('Click here to re-send the verification email.') }}
                        </button>
                    </p>

                    @if (session('status') === 'verification-link-sent')
                        <p class="mt-2 font-medium text-sm text-green-600 dark:text-green-400">
                            {{ __('A new verification link has been sent to your email address.') }}
                        </p>
                    @endif
                </div>
            @endif
        </div>

        <div>
            <x-input-label for="file_no" :value="__('File no')" />
            <x-text-input id="file_no" name="file_no" type="text" class="mt-1 block w-full" :value="old('name', $user->file_no)"
                required autofocus autocomplete="file_no" />
            <x-input-error class="mt-2" :messages="$errors->get('file_no')" />
        </div>
        <div>
            <x-input-label for="iqama_no" :value="__('Iqama no')" />
            <x-text-input id="iqama_no" name="iqama_no" type="text" class="mt-1 block w-full" :value="old('name', $user->iqama_no)"
                required autofocus autocomplete="iqama_no" />
            <x-input-error class="mt-2" :messages="$errors->get('iqama_no')" />
        </div>

        <div>
            <x-input-label for="department_id" :value="__('Department')" />
            <select id="department_id" name="department_id"
                class="mt-1 block w-full border-gray-300 rounded-md shadow-sm focus:border-blue-300 focus:ring focus:ring-blue-200 focus:ring-opacity-50">
                <option value="">{{ __('Select Department') }}</option>
                @foreach ($departments as $department)
                    <option value="{{ $department->id }}"
                        {{ old('department_id', $user->department_id) == $department->id ? 'selected' : '' }}>
                        {{ $department->name }}
                    </option>
                @endforeach
            </select>
            <x-input-error class="mt-2" :messages="$errors->get('department_id')" />
        </div>

        <div class="flex items-center mt-4">
            <x-input-label for="is_manager" :value="__('Is Manager')" />
            <div class="ml-3 relative">
                <label for="is_manager" class="cursor-pointer">
                    <input id="is_manager" name="is_manager" type="checkbox" class="hidden"
                        {{ old('is_manager',$user->hasRole('manager')) ? 'checked' : '' }} />
                    <div class="block w-10 h-6 bg-gray-200 rounded-full shadow-inner"></div>
                    <div
                        class="dot absolute left-1 top-1 w-4 h-4 bg-white rounded-full transition transform 
                        {{ old('is_manager', $user->hasRole('manager')) ? 'translate-x-full bg-blue-600' : 'bg-gray-400' }}">
                    </div>
                </label>
            </div>
            <x-input-error class="mt-2" :messages="$errors->get('is_manager')" />
        </div>



        <div class="flex items-center gap-4">
            <x-primary-button>{{ __('Save') }}</x-primary-button>

            @if (session('status') === 'profile-updated')
                <p x-data="{ show: true }" x-show="show" x-transition x-init="setTimeout(() => show = false, 2000)"
                    class="text-sm text-gray-600 dark:text-gray-400">{{ __('Saved.') }}</p>
            @endif
        </div>
    </form>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const toggle = document.getElementById('is_manager');
            const dot = toggle.nextElementSibling.querySelector('.dot');

            toggle.addEventListener('change', function() {
                dot.classList.toggle('translate-x-full');
                dot.classList.toggle('bg-blue-600');
            });
        });
    </script>
</section>
